DoubleConverter class

double 转换

Implemented types

Constructors

DoubleConverter({bool allowOtherTypes = true})
const

Properties

allowOtherTypes bool
是否允许其他类型转换 如 bool 转 double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(dynamic json) double?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(double? object) double?
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited