Method enum

请求方法, dio 内部会转成大写

Inheritance
Available extensions

Values

delete → const Method

delete

get → const Method

get

head

patch → const Method

patch

post → const Method

post

put → const Method

put

download → const Method

download

upload → const Method

upload

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
methodName String
获取方法名
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Method>
A constant List of the values in this enum, in order of their declaration.